WebBrowser/WebBrowserView.py

changeset 5740
292538236234
parent 5736
000ea446ff4b
child 5752
1860eca908e4
child 5784
362bbcc49ac1
--- a/WebBrowser/WebBrowserView.py	Mon May 15 18:36:49 2017 +0200
+++ b/WebBrowser/WebBrowserView.py	Tue May 16 18:41:29 2017 +0200
@@ -1288,8 +1288,8 @@
         if self.__mw and self.__mw.isFullScreen():
             if self.__mw.isFullScreenNavigationVisible():
                 self.__mw.hideFullScreenNavigation()
-            elif evt.y() < 5:
-                # mouse is within 5px to the top
+            elif evt.y() < 10:
+                # mouse is within 10px to the top
                 self.__mw.showFullScreenNavigation()
         
         if WebBrowserWindow.autoScroller().mouseMove(evt):

eric ide

mercurial